@@ -3,7 +3,7 @@ from django.utils.translation import ugettext_lazy as _
 
 
 class Address(models.Model):
-    profile = models.ForeignKey('profiles.Profile')
+    primary = models.BooleanField(default=False)
     address1 = models.CharField(max_length=255, verbose_name=_('address'), null=True, blank=True)
     address2 = models.CharField(max_length=255, verbose_name=_('address 2'), null=True, blank=True)
     city = models.CharField(max_length=255, verbose_name=_('town/city'), null=True, blank=True)
