@@ -1,4 +1,5 @@
 from django.conf import settings
+from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.contrib.sites.models import Site
 from django.core.urlresolvers import reverse
@@ -22,12 +23,11 @@ class ProfileView(TemplateView):
 @class_view_decorator(login_required)
 class ProfileEdit(UpdateView):
     form_class = ProfileForm
-    template_name = 'profiles/profile_form.html'
 
     def form_valid(self, form):
-        instance = super(ProfileEdit, self).form_valid(form)
-        self.request.user.message_set.create(message='Your profile has been updated.')
-        return instance
+        response = super(ProfileEdit, self).form_valid(form)
+        messages.info(self.request, 'Your profile has been updated.')
+        return response
 
     def get_context_data(self, **kwargs):
         context = super(ProfileEdit, self).get_context_data(**kwargs)
